==> jc-1.4.0.tar.gz: gnu/java/locale/LocaleInformation__5flv__5fLV.h <==
// public class gnu.java.locale.LocaleInformation_lv_LV

// class file dependencies
// @dep_class 579bbbb6ccbe135 gnu_java_locale_LocaleInformation__5flv__5fLV
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5flv__5fLV_H_
#define _JC_gnu_java_locale_LocaleInformation__5flv__5fLV_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$sub_refs	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$refs	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$nonrefs	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$object	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$fields_struct	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vmethods	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtable	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtype	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$fields_struct {
	_jc_object_array	*contents;
};
extern _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$fields_struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$object *);

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$object *);
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vmethods	gnu_java_locale_LocaleInformation__5flv__5fLV;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$refs {
    _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$sub_refs	gnu_java_locale_LocaleInformation__5flv__5fLV;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$sub_nonrefs	gnu_java_locale_LocaleInformation__5flv__5fLV;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$object {
	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtype _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5flv__5fLV, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5flv__5fLV_H_ */

==> jc-1.4.5.tar.gz: gnu/java/locale/LocaleInformation__5flv__5fLV.h <==
// public class gnu.java.locale.LocaleInformation_lv_LV

// class file dependencies
// @dep_class 579bbbb6ccbe135 gnu_java_locale_LocaleInformation__5flv__5fLV
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5flv__5fLV_H_
#define _JC_gnu_java_locale_LocaleInformation__5flv__5fLV_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$sub_refs	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$refs	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$nonrefs	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$object	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$fields_struct	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vmethods	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtable	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtype	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$fields_struct {
	_jc_object_array	*contents;
};
extern _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$fields_struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vmethods	gnu_java_locale_LocaleInformation__5flv__5fLV;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$refs {
    _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$sub_refs	gnu_java_locale_LocaleInformation__5flv__5fLV;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$sub_nonrefs	gnu_java_locale_LocaleInformation__5flv__5fLV;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$object {
	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5flv__5fLV$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$vtype _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5flv__5fLV, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5flv__5fLV$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5flv__5fLV_H_ */
